/*
Copyright (c) 2007 Health Market Science, Inc.

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

You can contact Health Market Science at info@healthmarketscience.com
or at the following address:

Health Market Science
2700 Horizon Drive
Suite 200
King of Prussia, PA 19406
*/

package com.healthmarketscience.common.util;

import java.io.IOException;

/**
 * Simple subclass for objects wishing to use the AppendableExt/Appendee
 * interface in new class hierarchies.  The {@link #toString()} method is
 * overridden to call the {@link #appendTo} method, so a subclass need only
 * provide a new implementation for the {@code appendTo()} method.  The
 * default {@code appendTo()} implementation appends the result of calling
 * {@link Object#toString}.  Also adds a {@link #toString(int)} method for
 * specifying the initial size of the underlying StringBuilder.
 *
 * @author James Ahlborn
 */
public class AppendeeObject
  implements Appendee
{
  public AppendeeObject() {}

  public void appendTo(AppendableExt a) throws IOException {
    // append Object.toString() to the AppendableExt
    a.append(super.toString());
  }

  public String toString(int size) {
    return(new AppendableExtWrapper(size)).append(this).toString();
  }
  
  @Override
  public String toString() {
    return(new AppendableExtWrapper()).append(this).toString();
  }
  
}
